# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/smartereye.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/smartereye.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/drivers/proto/smartereye.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"\x87\x01\n\x0fLdwLaneBoundary\x12\x0e\n\x06\x64\x65gree\x18\x01 \x01(\x05\x12\x13\n\x0b\x63\x30_position\x18\x02 \x01(\x01\x12\x18\n\x10\x63\x31_heading_angle\x18\x03 \x01(\x01\x12\x14\n\x0c\x63\x32_curvature\x18\x04 \x01(\x01\x12\x1f\n\x17\x63\x33_curvature_derivative\x18\x05 \x01(\x01\"\xc7\x01\n\x07LdwLane\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12+\n\x05style\x18\x03 \x01(\x0e\x32\x1c.apollo.drivers.LdwLaneStyle\x12\x36\n\rleft_boundary\x18\x04 \x01(\x0b\x32\x1f.apollo.drivers.LdwLaneBoundary\x12\x37\n\x0eright_boundary\x18\x05 \x01(\x0b\x32\x1f.apollo.drivers.LdwLaneBoundary\"\x8e\x02\n\nLdwRoadway\x12\x0f\n\x07width_0\x18\x01 \x01(\x05\x12\x0f\n\x07width_1\x18\x02 \x01(\x05\x12\x0f\n\x07width_2\x18\x03 \x01(\x05\x12\x13\n\x0bis_tracking\x18\x04 \x01(\x08\x12*\n\tleft_lane\x18\x05 \x01(\x0b\x32\x17.apollo.drivers.LdwLane\x12+\n\nright_lane\x18\x06 \x01(\x0b\x32\x17.apollo.drivers.LdwLane\x12.\n\radj_left_lane\x18\x07 \x01(\x0b\x32\x17.apollo.drivers.LdwLane\x12/\n\x0e\x61\x64j_right_lane\x18\x08 \x01(\x0b\x32\x17.apollo.drivers.LdwLane\"\xcb\x01\n\x0bLdwLensInfo\x12\x15\n\rx_image_focal\x18\x01 \x01(\x02\x12\x15\n\ry_image_focal\x18\x02 \x01(\x02\x12\x1a\n\x12xratio_focal_pixel\x18\x03 \x01(\x02\x12\x1a\n\x12yratio_focal_pixel\x18\x04 \x01(\x02\x12\x16\n\x0emountingheight\x18\x05 \x01(\x02\x12\x0e\n\x06mcosrx\x18\x06 \x01(\x02\x12\x0e\n\x06msinrx\x18\x07 \x01(\x02\x12\x0e\n\x06mcosry\x18\x08 \x01(\x02\x12\x0e\n\x06msinry\x18\t \x01(\x02\"\xce\x01\n\x0cLdwDataPacks\x12+\n\x07roadway\x18\x01 \x01(\x0b\x32\x1a.apollo.drivers.LdwRoadway\x12\x31\n\nsoftstatus\x18\x02 \x01(\x0e\x32\x1d.apollo.drivers.LdwSoftStatus\x12\x33\n\x0bsteerstatus\x18\x03 \x01(\x0e\x32\x1e.apollo.drivers.LdwSteerStatus\x12)\n\x04lens\x18\x04 \x01(\x0b\x32\x1b.apollo.drivers.LdwLensInfo\"\x82\t\n\x0eOutputObstacle\x12\x14\n\x0c\x63urrentspeed\x18\x01 \x01(\x02\x12\x11\n\tframerate\x18\x02 \x01(\x02\x12\x0f\n\x07trackid\x18\x03 \x01(\r\x12\x15\n\rtrackframenum\x18\x04 \x01(\r\x12\x12\n\nstatelabel\x18\x05 \x01(\r\x12\x12\n\nclasslabel\x18\x06 \x01(\r\x12\x17\n\x0f\x63ontinuouslabel\x18\x07 \x01(\r\x12\x1c\n\x14\x66uzzyestimationvalid\x18\x08 \x01(\r\x12\x44\n\x0cobstacletype\x18\t \x01(\x0e\x32..apollo.drivers.OutputObstacle.RecognitionType\x12\x0f\n\x07\x61vgdisp\x18\n \x01(\x02\x12\x14\n\x0c\x61vgdistancez\x18\x0b \x01(\x02\x12\x15\n\rneardistancez\x18\x0c \x01(\x02\x12\x14\n\x0c\x66\x61rdistancez\x18\r \x01(\x02\x12\x13\n\x0breal3dleftx\x18\x0e \x01(\x02\x12\x14\n\x0creal3drightx\x18\x0f \x01(\x02\x12\x15\n\rreal3dcenterx\x18\x10 \x01(\x02\x12\x11\n\treal3dupy\x18\x11 \x01(\x02\x12\x12\n\nreal3dlowy\x18\x12 \x01(\x02\x12\x13\n\x0b\x66irstpointx\x18\x13 \x01(\r\x12\x13\n\x0b\x66irstpointy\x18\x14 \x01(\r\x12\x14\n\x0csecondpointx\x18\x15 \x01(\r\x12\x14\n\x0csecondpointy\x18\x16 \x01(\r\x12\x13\n\x0bthirdpointx\x18\x17 \x01(\r\x12\x13\n\x0bthirdpointy\x18\x18 \x01(\r\x12\x14\n\x0c\x66ourthpointx\x18\x19 \x01(\r\x12\x14\n\x0c\x66ourthpointy\x18\x1a \x01(\r\x12\x1e\n\x16\x66uzzyrelativedistancez\x18\x1b \x01(\x02\x12\x1b\n\x13\x66uzzyrelativespeedz\x18\x1c \x01(\x02\x12\x1b\n\x13\x66uzzycollisiontimez\x18\x1d \x01(\x02\x12\x17\n\x0f\x66uzzycollisionx\x18\x1e \x01(\r\x12\x14\n\x0c\x66uzzy3dwidth\x18\x1f \x01(\x02\x12\x16\n\x0e\x66uzzy3dcenterx\x18  \x01(\x02\x12\x14\n\x0c\x66uzzy3dleftx\x18! \x01(\x02\x12\x15\n\rfuzzy3drightx\x18\" \x01(\x02\x12\x15\n\rfuzzy3dheight\x18# \x01(\x02\x12\x12\n\nfuzzy3dupy\x18$ \x01(\x02\x12\x13\n\x0b\x66uzzy3dlowy\x18% \x01(\x02\x12!\n\x19\x66uzzyrelativespeedcenterx\x18& \x01(\x02\x12\x1f\n\x17\x66uzzyrelativespeedleftx\x18\' \x01(\x02\x12 \n\x18\x66uzzyrelativespeedrightx\x18( \x01(\x02\"\x9c\x01\n\x0fRecognitionType\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07VEHICLE\x10\x01\x12\x0e\n\nPEDESTRIAN\x10\x02\x12\t\n\x05\x43HILD\x10\x03\x12\x0b\n\x07\x42ICYCLE\x10\x04\x12\x08\n\x04MOTO\x10\x05\x12\t\n\x05TRUCK\x10\x06\x12\x07\n\x03\x42US\x10\x07\x12\n\n\x06OTHERS\x10\x08\x12\r\n\tESTIMATED\x10\t\x12\x0e\n\nCONTINUOUS\x10\n\"\xff\x01\n\x13SmartereyeObstacles\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x15\n\rnum_obstacles\x18\x02 \x01(\x05\x12R\n\x10output_obstacles\x18\x03 \x03(\x0b\x32\x38.apollo.drivers.SmartereyeObstacles.OutputObstaclesEntry\x1aV\n\x14OutputObstaclesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.apollo.drivers.OutputObstacle:\x02\x38\x01\"J\n\x12SmartereyeLanemark\x12\x34\n\x0elane_road_data\x18\x04 \x01(\x0b\x32\x1c.apollo.drivers.LdwDataPacks*S\n\x0bLdwVersions\x12\x12\n\x0eLDW_VERSION_C1\x10\x00\x12\x12\n\x0eLDW_VERSION_C2\x10\x01\x12\x1c\n\x18LDW_VERSION_FOUR_LANE_C2\x10\x02*\xf9\x01\n\x0cLdwLaneStyle\x12\x1c\n\x18LDW_LANE_STYLE_NONE_LANE\x10\x00\x12\x1f\n\x1bLDW_LANE_STYLE_PREDICT_LANE\x10\x01\x12\x1e\n\x1aLDW_LANE_STYLE_BROKEN_LANE\x10\x02\x12\x1d\n\x19LDW_LANE_STYLE_SOLID_LANE\x10\x03\x12%\n!LDW_LANE_STYLE_DOUBLE_BROKEN_LANE\x10\x04\x12$\n LDW_LANE_STYLE_DOUBLE_SOLID_LANE\x10\x05\x12\x1e\n\x1aLDW_LANE_STYLE_TRIPLE_LANE\x10\x06*\x9a\x01\n\x0eLdwSteerStatus\x12\x14\n\x10LDW_NORMAL_STEER\x10\x00\x12\x1b\n\x17LDW_STEER_ON_LEFT__LANE\x10\x01\x12\x1b\n\x17LDW_STEER_ON_RIGHT_LANE\x10\x02\x12\x1b\n\x17LDW_STEER_WARNING_LEFT_\x10\x03\x12\x1b\n\x17LDW_STEER_WARNING_RIGHT\x10\x04*\x8b\x01\n\rLdwSoftStatus\x12\x16\n\x12LDW_SOFT_DETECTION\x10\x00\x12\x1a\n\x16LDW_SOFT_SELF_LEARNING\x10\x01\x12\"\n\x1eLDW_SOFT_MANUAL_LEARNING_MODE0\x10\x02\x12\"\n\x1eLDW_SOFT_MANUAL_LEARNING_MODE1\x10\x03*U\n\x0fLdwWarningGrade\x12\x13\n\x0fLDW_WARNING_LOW\x10\x00\x12\x16\n\x12LDW_WARNING_NORMAL\x10\x01\x12\x15\n\x11LDW_WARNING_HIGHT\x10\x02'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_LDWVERSIONS = _descriptor.EnumDescriptor(
  name='LdwVersions',
  full_name='apollo.drivers.LdwVersions',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LDW_VERSION_C1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_VERSION_C2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_VERSION_FOUR_LANE_C2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2612,
  serialized_end=2695,
)
_sym_db.RegisterEnumDescriptor(_LDWVERSIONS)

LdwVersions = enum_type_wrapper.EnumTypeWrapper(_LDWVERSIONS)
_LDWLANESTYLE = _descriptor.EnumDescriptor(
  name='LdwLaneStyle',
  full_name='apollo.drivers.LdwLaneStyle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_NONE_LANE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_PREDICT_LANE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_BROKEN_LANE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_SOLID_LANE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_DOUBLE_BROKEN_LANE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_DOUBLE_SOLID_LANE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_LANE_STYLE_TRIPLE_LANE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2698,
  serialized_end=2947,
)
_sym_db.RegisterEnumDescriptor(_LDWLANESTYLE)

LdwLaneStyle = enum_type_wrapper.EnumTypeWrapper(_LDWLANESTYLE)
_LDWSTEERSTATUS = _descriptor.EnumDescriptor(
  name='LdwSteerStatus',
  full_name='apollo.drivers.LdwSteerStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LDW_NORMAL_STEER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_STEER_ON_LEFT__LANE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_STEER_ON_RIGHT_LANE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_STEER_WARNING_LEFT_', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_STEER_WARNING_RIGHT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2950,
  serialized_end=3104,
)
_sym_db.RegisterEnumDescriptor(_LDWSTEERSTATUS)

LdwSteerStatus = enum_type_wrapper.EnumTypeWrapper(_LDWSTEERSTATUS)
_LDWSOFTSTATUS = _descriptor.EnumDescriptor(
  name='LdwSoftStatus',
  full_name='apollo.drivers.LdwSoftStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LDW_SOFT_DETECTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_SOFT_SELF_LEARNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_SOFT_MANUAL_LEARNING_MODE0', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_SOFT_MANUAL_LEARNING_MODE1', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3107,
  serialized_end=3246,
)
_sym_db.RegisterEnumDescriptor(_LDWSOFTSTATUS)

LdwSoftStatus = enum_type_wrapper.EnumTypeWrapper(_LDWSOFTSTATUS)
_LDWWARNINGGRADE = _descriptor.EnumDescriptor(
  name='LdwWarningGrade',
  full_name='apollo.drivers.LdwWarningGrade',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LDW_WARNING_LOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_WARNING_NORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDW_WARNING_HIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3248,
  serialized_end=3333,
)
_sym_db.RegisterEnumDescriptor(_LDWWARNINGGRADE)

LdwWarningGrade = enum_type_wrapper.EnumTypeWrapper(_LDWWARNINGGRADE)
LDW_VERSION_C1 = 0
LDW_VERSION_C2 = 1
LDW_VERSION_FOUR_LANE_C2 = 2
LDW_LANE_STYLE_NONE_LANE = 0
LDW_LANE_STYLE_PREDICT_LANE = 1
LDW_LANE_STYLE_BROKEN_LANE = 2
LDW_LANE_STYLE_SOLID_LANE = 3
LDW_LANE_STYLE_DOUBLE_BROKEN_LANE = 4
LDW_LANE_STYLE_DOUBLE_SOLID_LANE = 5
LDW_LANE_STYLE_TRIPLE_LANE = 6
LDW_NORMAL_STEER = 0
LDW_STEER_ON_LEFT__LANE = 1
LDW_STEER_ON_RIGHT_LANE = 2
LDW_STEER_WARNING_LEFT_ = 3
LDW_STEER_WARNING_RIGHT = 4
LDW_SOFT_DETECTION = 0
LDW_SOFT_SELF_LEARNING = 1
LDW_SOFT_MANUAL_LEARNING_MODE0 = 2
LDW_SOFT_MANUAL_LEARNING_MODE1 = 3
LDW_WARNING_LOW = 0
LDW_WARNING_NORMAL = 1
LDW_WARNING_HIGHT = 2


_OUTPUTOBSTACLE_RECOGNITIONTYPE = _descriptor.EnumDescriptor(
  name='RecognitionType',
  full_name='apollo.drivers.OutputObstacle.RecognitionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHILD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOTO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRUCK', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHERS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESTIMATED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTINUOUS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2120,
  serialized_end=2276,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTOBSTACLE_RECOGNITIONTYPE)


_LDWLANEBOUNDARY = _descriptor.Descriptor(
  name='LdwLaneBoundary',
  full_name='apollo.drivers.LdwLaneBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='degree', full_name='apollo.drivers.LdwLaneBoundary.degree', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c0_position', full_name='apollo.drivers.LdwLaneBoundary.c0_position', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c1_heading_angle', full_name='apollo.drivers.LdwLaneBoundary.c1_heading_angle', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c2_curvature', full_name='apollo.drivers.LdwLaneBoundary.c2_curvature', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c3_curvature_derivative', full_name='apollo.drivers.LdwLaneBoundary.c3_curvature_derivative', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=229,
)


_LDWLANE = _descriptor.Descriptor(
  name='LdwLane',
  full_name='apollo.drivers.LdwLane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.LdwLane.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.LdwLane.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='apollo.drivers.LdwLane.style', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='apollo.drivers.LdwLane.left_boundary', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='apollo.drivers.LdwLane.right_boundary', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=431,
)


_LDWROADWAY = _descriptor.Descriptor(
  name='LdwRoadway',
  full_name='apollo.drivers.LdwRoadway',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width_0', full_name='apollo.drivers.LdwRoadway.width_0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_1', full_name='apollo.drivers.LdwRoadway.width_1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_2', full_name='apollo.drivers.LdwRoadway.width_2', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tracking', full_name='apollo.drivers.LdwRoadway.is_tracking', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_lane', full_name='apollo.drivers.LdwRoadway.left_lane', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_lane', full_name='apollo.drivers.LdwRoadway.right_lane', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adj_left_lane', full_name='apollo.drivers.LdwRoadway.adj_left_lane', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adj_right_lane', full_name='apollo.drivers.LdwRoadway.adj_right_lane', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=704,
)


_LDWLENSINFO = _descriptor.Descriptor(
  name='LdwLensInfo',
  full_name='apollo.drivers.LdwLensInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x_image_focal', full_name='apollo.drivers.LdwLensInfo.x_image_focal', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_image_focal', full_name='apollo.drivers.LdwLensInfo.y_image_focal', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xratio_focal_pixel', full_name='apollo.drivers.LdwLensInfo.xratio_focal_pixel', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yratio_focal_pixel', full_name='apollo.drivers.LdwLensInfo.yratio_focal_pixel', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mountingheight', full_name='apollo.drivers.LdwLensInfo.mountingheight', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mcosrx', full_name='apollo.drivers.LdwLensInfo.mcosrx', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msinrx', full_name='apollo.drivers.LdwLensInfo.msinrx', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mcosry', full_name='apollo.drivers.LdwLensInfo.mcosry', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msinry', full_name='apollo.drivers.LdwLensInfo.msinry', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=910,
)


_LDWDATAPACKS = _descriptor.Descriptor(
  name='LdwDataPacks',
  full_name='apollo.drivers.LdwDataPacks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roadway', full_name='apollo.drivers.LdwDataPacks.roadway', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='softstatus', full_name='apollo.drivers.LdwDataPacks.softstatus', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steerstatus', full_name='apollo.drivers.LdwDataPacks.steerstatus', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lens', full_name='apollo.drivers.LdwDataPacks.lens', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=913,
  serialized_end=1119,
)


_OUTPUTOBSTACLE = _descriptor.Descriptor(
  name='OutputObstacle',
  full_name='apollo.drivers.OutputObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentspeed', full_name='apollo.drivers.OutputObstacle.currentspeed', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framerate', full_name='apollo.drivers.OutputObstacle.framerate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trackid', full_name='apollo.drivers.OutputObstacle.trackid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trackframenum', full_name='apollo.drivers.OutputObstacle.trackframenum', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statelabel', full_name='apollo.drivers.OutputObstacle.statelabel', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classlabel', full_name='apollo.drivers.OutputObstacle.classlabel', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continuouslabel', full_name='apollo.drivers.OutputObstacle.continuouslabel', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyestimationvalid', full_name='apollo.drivers.OutputObstacle.fuzzyestimationvalid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacletype', full_name='apollo.drivers.OutputObstacle.obstacletype', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgdisp', full_name='apollo.drivers.OutputObstacle.avgdisp', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgdistancez', full_name='apollo.drivers.OutputObstacle.avgdistancez', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neardistancez', full_name='apollo.drivers.OutputObstacle.neardistancez', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fardistancez', full_name='apollo.drivers.OutputObstacle.fardistancez', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real3dleftx', full_name='apollo.drivers.OutputObstacle.real3dleftx', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real3drightx', full_name='apollo.drivers.OutputObstacle.real3drightx', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real3dcenterx', full_name='apollo.drivers.OutputObstacle.real3dcenterx', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real3dupy', full_name='apollo.drivers.OutputObstacle.real3dupy', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real3dlowy', full_name='apollo.drivers.OutputObstacle.real3dlowy', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstpointx', full_name='apollo.drivers.OutputObstacle.firstpointx', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstpointy', full_name='apollo.drivers.OutputObstacle.firstpointy', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondpointx', full_name='apollo.drivers.OutputObstacle.secondpointx', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondpointy', full_name='apollo.drivers.OutputObstacle.secondpointy', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thirdpointx', full_name='apollo.drivers.OutputObstacle.thirdpointx', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thirdpointy', full_name='apollo.drivers.OutputObstacle.thirdpointy', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fourthpointx', full_name='apollo.drivers.OutputObstacle.fourthpointx', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fourthpointy', full_name='apollo.drivers.OutputObstacle.fourthpointy', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyrelativedistancez', full_name='apollo.drivers.OutputObstacle.fuzzyrelativedistancez', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyrelativespeedz', full_name='apollo.drivers.OutputObstacle.fuzzyrelativespeedz', index=27,
      number=28, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzycollisiontimez', full_name='apollo.drivers.OutputObstacle.fuzzycollisiontimez', index=28,
      number=29, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzycollisionx', full_name='apollo.drivers.OutputObstacle.fuzzycollisionx', index=29,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dwidth', full_name='apollo.drivers.OutputObstacle.fuzzy3dwidth', index=30,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dcenterx', full_name='apollo.drivers.OutputObstacle.fuzzy3dcenterx', index=31,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dleftx', full_name='apollo.drivers.OutputObstacle.fuzzy3dleftx', index=32,
      number=33, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3drightx', full_name='apollo.drivers.OutputObstacle.fuzzy3drightx', index=33,
      number=34, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dheight', full_name='apollo.drivers.OutputObstacle.fuzzy3dheight', index=34,
      number=35, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dupy', full_name='apollo.drivers.OutputObstacle.fuzzy3dupy', index=35,
      number=36, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzy3dlowy', full_name='apollo.drivers.OutputObstacle.fuzzy3dlowy', index=36,
      number=37, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyrelativespeedcenterx', full_name='apollo.drivers.OutputObstacle.fuzzyrelativespeedcenterx', index=37,
      number=38, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyrelativespeedleftx', full_name='apollo.drivers.OutputObstacle.fuzzyrelativespeedleftx', index=38,
      number=39, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzyrelativespeedrightx', full_name='apollo.drivers.OutputObstacle.fuzzyrelativespeedrightx', index=39,
      number=40, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OUTPUTOBSTACLE_RECOGNITIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1122,
  serialized_end=2276,
)


_SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY = _descriptor.Descriptor(
  name='OutputObstaclesEntry',
  full_name='apollo.drivers.SmartereyeObstacles.OutputObstaclesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.drivers.SmartereyeObstacles.OutputObstaclesEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.drivers.SmartereyeObstacles.OutputObstaclesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2534,
)

_SMARTEREYEOBSTACLES = _descriptor.Descriptor(
  name='SmartereyeObstacles',
  full_name='apollo.drivers.SmartereyeObstacles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.SmartereyeObstacles.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_obstacles', full_name='apollo.drivers.SmartereyeObstacles.num_obstacles', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_obstacles', full_name='apollo.drivers.SmartereyeObstacles.output_obstacles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2534,
)


_SMARTEREYELANEMARK = _descriptor.Descriptor(
  name='SmartereyeLanemark',
  full_name='apollo.drivers.SmartereyeLanemark',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_road_data', full_name='apollo.drivers.SmartereyeLanemark.lane_road_data', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2536,
  serialized_end=2610,
)

_LDWLANE.fields_by_name['style'].enum_type = _LDWLANESTYLE
_LDWLANE.fields_by_name['left_boundary'].message_type = _LDWLANEBOUNDARY
_LDWLANE.fields_by_name['right_boundary'].message_type = _LDWLANEBOUNDARY
_LDWROADWAY.fields_by_name['left_lane'].message_type = _LDWLANE
_LDWROADWAY.fields_by_name['right_lane'].message_type = _LDWLANE
_LDWROADWAY.fields_by_name['adj_left_lane'].message_type = _LDWLANE
_LDWROADWAY.fields_by_name['adj_right_lane'].message_type = _LDWLANE
_LDWDATAPACKS.fields_by_name['roadway'].message_type = _LDWROADWAY
_LDWDATAPACKS.fields_by_name['softstatus'].enum_type = _LDWSOFTSTATUS
_LDWDATAPACKS.fields_by_name['steerstatus'].enum_type = _LDWSTEERSTATUS
_LDWDATAPACKS.fields_by_name['lens'].message_type = _LDWLENSINFO
_OUTPUTOBSTACLE.fields_by_name['obstacletype'].enum_type = _OUTPUTOBSTACLE_RECOGNITIONTYPE
_OUTPUTOBSTACLE_RECOGNITIONTYPE.containing_type = _OUTPUTOBSTACLE
_SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY.fields_by_name['value'].message_type = _OUTPUTOBSTACLE
_SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY.containing_type = _SMARTEREYEOBSTACLES
_SMARTEREYEOBSTACLES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_SMARTEREYEOBSTACLES.fields_by_name['output_obstacles'].message_type = _SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY
_SMARTEREYELANEMARK.fields_by_name['lane_road_data'].message_type = _LDWDATAPACKS
DESCRIPTOR.message_types_by_name['LdwLaneBoundary'] = _LDWLANEBOUNDARY
DESCRIPTOR.message_types_by_name['LdwLane'] = _LDWLANE
DESCRIPTOR.message_types_by_name['LdwRoadway'] = _LDWROADWAY
DESCRIPTOR.message_types_by_name['LdwLensInfo'] = _LDWLENSINFO
DESCRIPTOR.message_types_by_name['LdwDataPacks'] = _LDWDATAPACKS
DESCRIPTOR.message_types_by_name['OutputObstacle'] = _OUTPUTOBSTACLE
DESCRIPTOR.message_types_by_name['SmartereyeObstacles'] = _SMARTEREYEOBSTACLES
DESCRIPTOR.message_types_by_name['SmartereyeLanemark'] = _SMARTEREYELANEMARK
DESCRIPTOR.enum_types_by_name['LdwVersions'] = _LDWVERSIONS
DESCRIPTOR.enum_types_by_name['LdwLaneStyle'] = _LDWLANESTYLE
DESCRIPTOR.enum_types_by_name['LdwSteerStatus'] = _LDWSTEERSTATUS
DESCRIPTOR.enum_types_by_name['LdwSoftStatus'] = _LDWSOFTSTATUS
DESCRIPTOR.enum_types_by_name['LdwWarningGrade'] = _LDWWARNINGGRADE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LdwLaneBoundary = _reflection.GeneratedProtocolMessageType('LdwLaneBoundary', (_message.Message,), {
  'DESCRIPTOR' : _LDWLANEBOUNDARY,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.LdwLaneBoundary)
  })
_sym_db.RegisterMessage(LdwLaneBoundary)

LdwLane = _reflection.GeneratedProtocolMessageType('LdwLane', (_message.Message,), {
  'DESCRIPTOR' : _LDWLANE,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.LdwLane)
  })
_sym_db.RegisterMessage(LdwLane)

LdwRoadway = _reflection.GeneratedProtocolMessageType('LdwRoadway', (_message.Message,), {
  'DESCRIPTOR' : _LDWROADWAY,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.LdwRoadway)
  })
_sym_db.RegisterMessage(LdwRoadway)

LdwLensInfo = _reflection.GeneratedProtocolMessageType('LdwLensInfo', (_message.Message,), {
  'DESCRIPTOR' : _LDWLENSINFO,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.LdwLensInfo)
  })
_sym_db.RegisterMessage(LdwLensInfo)

LdwDataPacks = _reflection.GeneratedProtocolMessageType('LdwDataPacks', (_message.Message,), {
  'DESCRIPTOR' : _LDWDATAPACKS,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.LdwDataPacks)
  })
_sym_db.RegisterMessage(LdwDataPacks)

OutputObstacle = _reflection.GeneratedProtocolMessageType('OutputObstacle', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTOBSTACLE,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.OutputObstacle)
  })
_sym_db.RegisterMessage(OutputObstacle)

SmartereyeObstacles = _reflection.GeneratedProtocolMessageType('SmartereyeObstacles', (_message.Message,), {

  'OutputObstaclesEntry' : _reflection.GeneratedProtocolMessageType('OutputObstaclesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY,
    '__module__' : 'modules.drivers.proto.smartereye_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.SmartereyeObstacles.OutputObstaclesEntry)
    })
  ,
  'DESCRIPTOR' : _SMARTEREYEOBSTACLES,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.SmartereyeObstacles)
  })
_sym_db.RegisterMessage(SmartereyeObstacles)
_sym_db.RegisterMessage(SmartereyeObstacles.OutputObstaclesEntry)

SmartereyeLanemark = _reflection.GeneratedProtocolMessageType('SmartereyeLanemark', (_message.Message,), {
  'DESCRIPTOR' : _SMARTEREYELANEMARK,
  '__module__' : 'modules.drivers.proto.smartereye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.SmartereyeLanemark)
  })
_sym_db.RegisterMessage(SmartereyeLanemark)


_SMARTEREYEOBSTACLES_OUTPUTOBSTACLESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/lane_graph.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/lane_graph.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/prediction/proto/lane_graph.proto\x12\x11\x61pollo.prediction\x1a#modules/common/proto/geometry.proto\x1a$modules/common/proto/pnc_point.proto\x1a modules/map/proto/map_lane.proto\"\xc4\x02\n\tLanePoint\x12(\n\x08position\x18\x01 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x12\n\x07heading\x18\x02 \x01(\x01:\x01\x30\x12\x10\n\x05width\x18\x03 \x01(\x01:\x01\x30\x12\x15\n\nrelative_s\x18\x04 \x01(\x01:\x01\x30\x12\x15\n\nrelative_l\x18\x05 \x01(\x01:\x01\x30\x12\x15\n\nangle_diff\x18\x06 \x01(\x01:\x01\x30\x12\x10\n\x05kappa\x18\x07 \x01(\x01:\x01\x30\x12@\n\rscenario_type\x18\x08 \x01(\x0e\x32).apollo.prediction.LanePoint.ScenarioType\x12\x13\n\x0bspeed_limit\x18\t \x01(\x01\"9\n\x0cScenarioType\x12\x0e\n\nURBAN_ROAD\x10\x00\x12\x0c\n\x08JUNCTION\x10\x01\x12\x0b\n\x07HIGHWAY\x10\x02\"\xdb\x01\n\x0bLaneSegment\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\x12\n\x07start_s\x18\x02 \x01(\x01:\x01\x30\x12\x10\n\x05\x65nd_s\x18\x03 \x01(\x01:\x01\x30\x12\x19\n\x0elane_turn_type\x18\x04 \x01(\r:\x01\x30\x12\x30\n\nlane_point\x18\x05 \x03(\x0b\x32\x1c.apollo.prediction.LanePoint\x12\x10\n\x05\x61\x64\x63_s\x18\x07 \x01(\x01:\x01\x30\x12\x1d\n\x12\x61\x64\x63_lane_point_idx\x18\x08 \x01(\x05:\x01\x30\x12\x17\n\x0ctotal_length\x18\x06 \x01(\x01:\x01\x30\"2\n\x0eNearbyObstacle\x12\n\n\x02id\x18\x01 \x01(\x05\x12\t\n\x01s\x18\x02 \x01(\x01\x12\t\n\x01l\x18\x03 \x01(\x01\"Z\n\x08StopSign\x12\x14\n\x0cstop_sign_id\x18\x01 \x01(\t\x12\x0f\n\x07lane_id\x18\x02 \x01(\t\x12\x0e\n\x06lane_s\x18\x03 \x01(\x01\x12\x17\n\x0flane_sequence_s\x18\x04 \x01(\x01\"\xff\x08\n\x0cLaneSequence\x12\x18\n\x10lane_sequence_id\x18\x01 \x01(\x05\x12\x34\n\x0clane_segment\x18\x02 \x03(\x0b\x32\x1e.apollo.prediction.LaneSegment\x12\x1f\n\x14\x61\x64\x63_lane_segment_idx\x18\x17 \x01(\x05:\x01\x30\x12,\n\npath_point\x18\x08 \x03(\x0b\x32\x18.apollo.common.PathPoint\x12.\n\tlane_type\x18\x16 \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneType\x12\x0e\n\x06lane_s\x18\x11 \x01(\x01\x12\x0e\n\x06lane_l\x18\x12 \x01(\x01\x12\x17\n\x0fvehicle_on_lane\x18\n \x01(\x08\x12:\n\x0fnearby_obstacle\x18\x03 \x03(\x0b\x32!.apollo.prediction.NearbyObstacle\x12.\n\tstop_sign\x18\x14 \x01(\x0b\x32\x1b.apollo.prediction.StopSign\x12\x14\n\x0cright_of_way\x18\x15 \x01(\x05\x12:\n\x08\x66\x65\x61tures\x18\x04 \x01(\x0b\x32(.apollo.prediction.LaneSequence.Features\x12\x10\n\x05label\x18\x05 \x01(\x05:\x01\x30\x12\x16\n\x0bprobability\x18\x06 \x01(\x01:\x01\x30\x12\x17\n\x0c\x61\x63\x63\x65leration\x18\x07 \x01(\x01:\x01\x30\x12\x1b\n\x13time_to_lane_center\x18\x10 \x01(\x01\x12\x19\n\x11time_to_lane_edge\x18\x13 \x01(\x01\x12\x43\n\rbehavior_type\x18\t \x01(\x0e\x32,.apollo.prediction.LaneSequence.BehaviorType\x12\x35\n\x0f\x63urr_lane_point\x18\x0b \x03(\x0b\x32\x1c.apollo.prediction.LanePoint\x12\x39\n\x13left_neighbor_point\x18\x0c \x03(\x0b\x32\x1c.apollo.prediction.LanePoint\x12:\n\x14right_neighbor_point\x18\r \x03(\x0b\x32\x1c.apollo.prediction.LanePoint\x12?\n\x14left_nearby_obstacle\x18\x0e \x03(\x0b\x32!.apollo.prediction.NearbyObstacle\x12@\n\x15right_nearby_obstacle\x18\x0f \x03(\x0b\x32!.apollo.prediction.NearbyObstacle\x1a \n\x08\x46\x65\x61tures\x12\x14\n\x0cmlp_features\x18\x01 \x03(\x01\"\x95\x01\n\x0c\x42\x65haviorType\x12\x11\n\rNOT_GOTO_LANE\x10\x01\x12\x12\n\x0e\x43ONSTANT_SPEED\x10\x02\x12\x16\n\x12SMALL_ACCELERATION\x10\x03\x12\x16\n\x12LARGE_ACCELERATION\x10\x04\x12\x16\n\x12SMALL_DECELERATION\x10\x05\x12\x16\n\x12LARGE_DECELERATION\x10\x06\"C\n\tLaneGraph\x12\x36\n\rlane_sequence\x18\x01 \x03(\x0b\x32\x1f.apollo.prediction.LaneSequence\"T\n\x0cLaneObstacle\x12\x13\n\x0bobstacle_id\x18\x01 \x01(\x05\x12\x0f\n\x07lane_id\x18\x02 \x01(\t\x12\x0e\n\x06lane_s\x18\x03 \x01(\x01\x12\x0e\n\x06lane_l\x18\x04 \x01(\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,])



_LANEPOINT_SCENARIOTYPE = _descriptor.EnumDescriptor(
  name='ScenarioType',
  full_name='apollo.prediction.LanePoint.ScenarioType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='URBAN_ROAD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=441,
  serialized_end=498,
)
_sym_db.RegisterEnumDescriptor(_LANEPOINT_SCENARIOTYPE)

_LANESEQUENCE_BEHAVIORTYPE = _descriptor.EnumDescriptor(
  name='BehaviorType',
  full_name='apollo.prediction.LaneSequence.BehaviorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_GOTO_LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSTANT_SPEED', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMALL_ACCELERATION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LARGE_ACCELERATION', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMALL_DECELERATION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LARGE_DECELERATION', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1869,
  serialized_end=2018,
)
_sym_db.RegisterEnumDescriptor(_LANESEQUENCE_BEHAVIORTYPE)


_LANEPOINT = _descriptor.Descriptor(
  name='LanePoint',
  full_name='apollo.prediction.LanePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.prediction.LanePoint.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.prediction.LanePoint.heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.prediction.LanePoint.width', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_s', full_name='apollo.prediction.LanePoint.relative_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_l', full_name='apollo.prediction.LanePoint.relative_l', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle_diff', full_name='apollo.prediction.LanePoint.angle_diff', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.prediction.LanePoint.kappa', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scenario_type', full_name='apollo.prediction.LanePoint.scenario_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.prediction.LanePoint.speed_limit', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANEPOINT_SCENARIOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=498,
)


_LANESEGMENT = _descriptor.Descriptor(
  name='LaneSegment',
  full_name='apollo.prediction.LaneSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.prediction.LaneSegment.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.prediction.LaneSegment.start_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.prediction.LaneSegment.end_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_turn_type', full_name='apollo.prediction.LaneSegment.lane_turn_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_point', full_name='apollo.prediction.LaneSegment.lane_point', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_s', full_name='apollo.prediction.LaneSegment.adc_s', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_lane_point_idx', full_name='apollo.prediction.LaneSegment.adc_lane_point_idx', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_length', full_name='apollo.prediction.LaneSegment.total_length', index=7,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=720,
)


_NEARBYOBSTACLE = _descriptor.Descriptor(
  name='NearbyObstacle',
  full_name='apollo.prediction.NearbyObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.NearbyObstacle.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.prediction.NearbyObstacle.s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.prediction.NearbyObstacle.l', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=772,
)


_STOPSIGN = _descriptor.Descriptor(
  name='StopSign',
  full_name='apollo.prediction.StopSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_sign_id', full_name='apollo.prediction.StopSign.stop_sign_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.prediction.StopSign.lane_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_s', full_name='apollo.prediction.StopSign.lane_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_sequence_s', full_name='apollo.prediction.StopSign.lane_sequence_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=864,
)


_LANESEQUENCE_FEATURES = _descriptor.Descriptor(
  name='Features',
  full_name='apollo.prediction.LaneSequence.Features',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mlp_features', full_name='apollo.prediction.LaneSequence.Features.mlp_features', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1834,
  serialized_end=1866,
)

_LANESEQUENCE = _descriptor.Descriptor(
  name='LaneSequence',
  full_name='apollo.prediction.LaneSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_sequence_id', full_name='apollo.prediction.LaneSequence.lane_sequence_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_segment', full_name='apollo.prediction.LaneSequence.lane_segment', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_lane_segment_idx', full_name='apollo.prediction.LaneSequence.adc_lane_segment_idx', index=2,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.prediction.LaneSequence.path_point', index=3,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.prediction.LaneSequence.lane_type', index=4,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_s', full_name='apollo.prediction.LaneSequence.lane_s', index=5,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_l', full_name='apollo.prediction.LaneSequence.lane_l', index=6,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_on_lane', full_name='apollo.prediction.LaneSequence.vehicle_on_lane', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearby_obstacle', full_name='apollo.prediction.LaneSequence.nearby_obstacle', index=8,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.prediction.LaneSequence.stop_sign', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_of_way', full_name='apollo.prediction.LaneSequence.right_of_way', index=10,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='apollo.prediction.LaneSequence.features', index=11,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.prediction.LaneSequence.label', index=12,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.prediction.LaneSequence.probability', index=13,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.prediction.LaneSequence.acceleration', index=14,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_lane_center', full_name='apollo.prediction.LaneSequence.time_to_lane_center', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_lane_edge', full_name='apollo.prediction.LaneSequence.time_to_lane_edge', index=16,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='behavior_type', full_name='apollo.prediction.LaneSequence.behavior_type', index=17,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curr_lane_point', full_name='apollo.prediction.LaneSequence.curr_lane_point', index=18,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_point', full_name='apollo.prediction.LaneSequence.left_neighbor_point', index=19,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_point', full_name='apollo.prediction.LaneSequence.right_neighbor_point', index=20,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_nearby_obstacle', full_name='apollo.prediction.LaneSequence.left_nearby_obstacle', index=21,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_nearby_obstacle', full_name='apollo.prediction.LaneSequence.right_nearby_obstacle', index=22,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LANESEQUENCE_FEATURES, ],
  enum_types=[
    _LANESEQUENCE_BEHAVIORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=2018,
)


_LANEGRAPH = _descriptor.Descriptor(
  name='LaneGraph',
  full_name='apollo.prediction.LaneGraph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_sequence', full_name='apollo.prediction.LaneGraph.lane_sequence', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2020,
  serialized_end=2087,
)


_LANEOBSTACLE = _descriptor.Descriptor(
  name='LaneObstacle',
  full_name='apollo.prediction.LaneObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.prediction.LaneObstacle.obstacle_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.prediction.LaneObstacle.lane_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_s', full_name='apollo.prediction.LaneObstacle.lane_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_l', full_name='apollo.prediction.LaneObstacle.lane_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2089,
  serialized_end=2173,
)

_LANEPOINT.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_LANEPOINT.fields_by_name['scenario_type'].enum_type = _LANEPOINT_SCENARIOTYPE
_LANEPOINT_SCENARIOTYPE.containing_type = _LANEPOINT
_LANESEGMENT.fields_by_name['lane_point'].message_type = _LANEPOINT
_LANESEQUENCE_FEATURES.containing_type = _LANESEQUENCE
_LANESEQUENCE.fields_by_name['lane_segment'].message_type = _LANESEGMENT
_LANESEQUENCE.fields_by_name['path_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATHPOINT
_LANESEQUENCE.fields_by_name['lane_type'].enum_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANE_LANETYPE
_LANESEQUENCE.fields_by_name['nearby_obstacle'].message_type = _NEARBYOBSTACLE
_LANESEQUENCE.fields_by_name['stop_sign'].message_type = _STOPSIGN
_LANESEQUENCE.fields_by_name['features'].message_type = _LANESEQUENCE_FEATURES
_LANESEQUENCE.fields_by_name['behavior_type'].enum_type = _LANESEQUENCE_BEHAVIORTYPE
_LANESEQUENCE.fields_by_name['curr_lane_point'].message_type = _LANEPOINT
_LANESEQUENCE.fields_by_name['left_neighbor_point'].message_type = _LANEPOINT
_LANESEQUENCE.fields_by_name['right_neighbor_point'].message_type = _LANEPOINT
_LANESEQUENCE.fields_by_name['left_nearby_obstacle'].message_type = _NEARBYOBSTACLE
_LANESEQUENCE.fields_by_name['right_nearby_obstacle'].message_type = _NEARBYOBSTACLE
_LANESEQUENCE_BEHAVIORTYPE.containing_type = _LANESEQUENCE
_LANEGRAPH.fields_by_name['lane_sequence'].message_type = _LANESEQUENCE
DESCRIPTOR.message_types_by_name['LanePoint'] = _LANEPOINT
DESCRIPTOR.message_types_by_name['LaneSegment'] = _LANESEGMENT
DESCRIPTOR.message_types_by_name['NearbyObstacle'] = _NEARBYOBSTACLE
DESCRIPTOR.message_types_by_name['StopSign'] = _STOPSIGN
DESCRIPTOR.message_types_by_name['LaneSequence'] = _LANESEQUENCE
DESCRIPTOR.message_types_by_name['LaneGraph'] = _LANEGRAPH
DESCRIPTOR.message_types_by_name['LaneObstacle'] = _LANEOBSTACLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LanePoint = _reflection.GeneratedProtocolMessageType('LanePoint', (_message.Message,), {
  'DESCRIPTOR' : _LANEPOINT,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LanePoint)
  })
_sym_db.RegisterMessage(LanePoint)

LaneSegment = _reflection.GeneratedProtocolMessageType('LaneSegment', (_message.Message,), {
  'DESCRIPTOR' : _LANESEGMENT,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneSegment)
  })
_sym_db.RegisterMessage(LaneSegment)

NearbyObstacle = _reflection.GeneratedProtocolMessageType('NearbyObstacle', (_message.Message,), {
  'DESCRIPTOR' : _NEARBYOBSTACLE,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.NearbyObstacle)
  })
_sym_db.RegisterMessage(NearbyObstacle)

StopSign = _reflection.GeneratedProtocolMessageType('StopSign', (_message.Message,), {
  'DESCRIPTOR' : _STOPSIGN,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.StopSign)
  })
_sym_db.RegisterMessage(StopSign)

LaneSequence = _reflection.GeneratedProtocolMessageType('LaneSequence', (_message.Message,), {

  'Features' : _reflection.GeneratedProtocolMessageType('Features', (_message.Message,), {
    'DESCRIPTOR' : _LANESEQUENCE_FEATURES,
    '__module__' : 'modules.prediction.proto.lane_graph_pb2'
    # @@protoc_insertion_point(class_scope:apollo.prediction.LaneSequence.Features)
    })
  ,
  'DESCRIPTOR' : _LANESEQUENCE,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneSequence)
  })
_sym_db.RegisterMessage(LaneSequence)
_sym_db.RegisterMessage(LaneSequence.Features)

LaneGraph = _reflection.GeneratedProtocolMessageType('LaneGraph', (_message.Message,), {
  'DESCRIPTOR' : _LANEGRAPH,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneGraph)
  })
_sym_db.RegisterMessage(LaneGraph)

LaneObstacle = _reflection.GeneratedProtocolMessageType('LaneObstacle', (_message.Message,), {
  'DESCRIPTOR' : _LANEOBSTACLE,
  '__module__' : 'modules.prediction.proto.lane_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneObstacle)
  })
_sym_db.RegisterMessage(LaneObstacle)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/guardian/proto/guardian_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/guardian/proto/guardian_conf.proto',
  package='apollo.guardian',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*modules/guardian/proto/guardian_conf.proto\x12\x0f\x61pollo.guardian\"\x91\x01\n\x0cGuardianConf\x12\x1e\n\x0fguardian_enable\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x32\n&guardian_cmd_emergency_stop_percentage\x18\x02 \x01(\x01:\x02\x35\x30\x12-\n!guardian_cmd_soft_stop_percentage\x18\x03 \x01(\x01:\x02\x32\x35'
)




_GUARDIANCONF = _descriptor.Descriptor(
  name='GuardianConf',
  full_name='apollo.guardian.GuardianConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='guardian_enable', full_name='apollo.guardian.GuardianConf.guardian_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guardian_cmd_emergency_stop_percentage', full_name='apollo.guardian.GuardianConf.guardian_cmd_emergency_stop_percentage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(50),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guardian_cmd_soft_stop_percentage', full_name='apollo.guardian.GuardianConf.guardian_cmd_soft_stop_percentage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=209,
)

DESCRIPTOR.message_types_by_name['GuardianConf'] = _GUARDIANCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GuardianConf = _reflection.GeneratedProtocolMessageType('GuardianConf', (_message.Message,), {
  'DESCRIPTOR' : _GUARDIANCONF,
  '__module__' : 'modules.guardian.proto.guardian_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.guardian.GuardianConf)
  })
_sym_db.RegisterMessage(GuardianConf)


# @@protoc_insertion_point(module_scope)
